@@ -79,7 +79,7 @@ class PerpMarketInstructionBuilder(MarketInstructionBuilder):
         return build_redeem_accrued_mango_instructions(self.context, self.wallet, self.perp_market, self.group, self.account, self.mngo_token_bank)
 
     def __str__(self) -> str:
-        return """« 𝙿𝚎𝚛𝚙𝙼𝚊𝚛𝚔𝚎𝚝𝙸𝚗𝚜𝚝𝚛𝚞𝚌𝚝𝚒𝚘𝚗𝚜 »"""
+        return """« PerpMarketInstructionBuilder »"""
 
 
 # # 🥭 PerpMarketOperations
@@ -99,7 +99,7 @@ class PerpMarketOperations(MarketOperations):
         self.perp_market: PerpMarket = perp_market
 
     def cancel_order(self, order: Order, ok_if_missing: bool = False) -> typing.Sequence[str]:
-        self.logger.info(f"Cancelling {self.market_name} order {order}.")
+        self._logger.info(f"Cancelling {self.market_name} order {order}.")
         signers: CombinableInstructions = CombinableInstructions.from_wallet(self.wallet)
         cancel: CombinableInstructions = self.market_instruction_builder.build_cancel_order_instructions(
             order, ok_if_missing=ok_if_missing)
@@ -112,7 +112,7 @@ class PerpMarketOperations(MarketOperations):
         client_id: int = self.context.generate_client_id()
         signers: CombinableInstructions = CombinableInstructions.from_wallet(self.wallet)
         order_with_client_id: Order = order.with_client_id(client_id)
-        self.logger.info(f"Placing {self.market_name} order {order_with_client_id}.")
+        self._logger.info(f"Placing {self.market_name} order {order_with_client_id}.")
         place: CombinableInstructions = self.market_instruction_builder.build_place_order_instructions(
             order_with_client_id)
         accounts_to_crank = self.perp_market.accounts_to_crank(self.context, self.account.address)
@@ -146,4 +146,4 @@ class PerpMarketOperations(MarketOperations):
         return list([o for o in [*orderbook.bids, *orderbook.asks] if o.owner == self.account.address])
 
     def __str__(self) -> str:
-        return f"""« 𝙿𝚎𝚛𝚙𝙼𝚊𝚛𝚔𝚎𝚝𝙾𝚙𝚎𝚛𝚊𝚝𝚒𝚘𝚗𝚜 [{self.market_name}] »"""
+        return f"""« PerpMarketOperations [{self.market_name}] »"""
